#include "ad9854.h"

/* AD9854-Daten anlegen */
void ad9854_set_data( uint8_t data )
{
   PORTA = data;
}

/* AD9854-Adresse anlegen */
void ad9854_set_addr( uint8_t addr )
{
   addr &= 0x3F;
   addr <<= 2;
   PORTD &= ~(0x3F<<2);
   PORTD |= addr;
}

/* AD9854-Reset */
void ad9854_reset( void )
{
   PORTB &= ~_MASTER_RESET;
   delay_ms(1);
   PORTB |= _MASTER_RESET;
   delay_ms(1);
   PORTB &= ~_MASTER_RESET;
   delay_ms(1);
}

/* AD9854 initialisieren */
void ad9854_init( void )
{
   PORTB |= _SP_SELECT;    // Parallel-Mode
   ad9854_reset();
}

/* AD9854-Register beschreiben */
void ad9854_write( uint8_t addr, uint8_t data )
{
   PORTC |= _WR;   // WR high
   ad9854_set_addr( addr );
   PORTC &= ~_WR;  // WR low
   ad9854_set_data( data );
   PORTC |= _WR;   // WR high
}

/* AD9854 Phase 1 einstellen */
void ad9854_set_phase_1(uint16_t v )
{
   ad9854_write( AD9854_PHASE1_L, v );
   ad9854_write( AD9854_PHASE1_H, v>>8 );
}

/* AD9854 Phase 2 einstellen */
void ad9854_set_phase_2(uint16_t v )
{
   ad9854_write( AD9854_PHASE2_L, v );
   ad9854_write( AD9854_PHASE2_H, v>>8 );
}

/* AD9854 Frequenz 1 einstellen */
void ad9854_set_freq_1(uint64_t f)
{
   ad9854_write( AD9854_FREQ1_0, f );
   ad9854_write( AD9854_FREQ1_1, f>>8 );
   ad9854_write( AD9854_FREQ1_2, f>>16 );
   ad9854_write( AD9854_FREQ1_3, f>>24 );
   ad9854_write( AD9854_FREQ1_4, f>>32 );
   ad9854_write( AD9854_FREQ1_5, f>>40 );
}

/* AD9854 Frequenz 2 einstellen */
void ad9854_set_freq_2(uint64_t f)
{
   ad9854_write( AD9854_FREQ2_0, f );
   ad9854_write( AD9854_FREQ2_1, f>>8 );
   ad9854_write( AD9854_FREQ2_2, f>>16 );
   ad9854_write( AD9854_FREQ2_3, f>>24 );
   ad9854_write( AD9854_FREQ2_4, f>>32 );
   ad9854_write( AD9854_FREQ2_5, f>>40 );
}

/* AD9854 Delta-Frequenz einstellen */
void ad9854_set_delta_freq(uint64_t f)
{
   ad9854_write( AD9854_DELTA_0, f );
   ad9854_write( AD9854_DELTA_1, f>>8 );
   ad9854_write( AD9854_DELTA_2, f>>16 );
   ad9854_write( AD9854_DELTA_3, f>>24 );
   ad9854_write( AD9854_DELTA_4, f>>32 );
   ad9854_write( AD9854_DELTA_5, f>>40 );
}

/* AD9854 Update-Clock einstellen */
void ad9854_set_update_clock(uint32_t v )
{
   ad9854_write( AD9854_UPDCLOCK_0, v );
   ad9854_write( AD9854_UPDCLOCK_1, v>>8 );
   ad9854_write( AD9854_UPDCLOCK_2, v>>16 );
   ad9854_write( AD9854_UPDCLOCK_3, v>>24 );
}

/* AD9854 Ramp-Rate Clock einstellen */
void ad9854_set_ramp_rate_clock( uint32_t v )
{
   ad9854_write( AD9854_RMPRTCLOCK_0, v );
   ad9854_write( AD9854_RMPRTCLOCK_1, v>>8 );
   ad9854_write( AD9854_RMPRTCLOCK_2, v>>16 );
}

/* AD9854 Control-Register beschreiben */
void ad9854_set_control_reg( uint32_t v )
{
   ad9854_write( AD9854_CONTROLWRD_0, v );
   ad9854_write( AD9854_CONTROLWRD_1, v>>8 );
   ad9854_write( AD9854_CONTROLWRD_2, v>>16 );
   ad9854_write( AD9854_CONTROLWRD_3, v>>24 );
}

/* AD9854 OSK-Ramp-Rate einstellen */
void ad9854_set_osk_ramp_rate(uint16_t v)
{
   ad9854_write( AD9854_OSKRMPRT, v );
}

/* AD9854 I-Amplitude einstellen */
void ad9854_set_mult_i(uint16_t v)
{
   ad9854_write( AD9854_OSKMULT_I_L, v );
   ad9854_write( AD9854_OSKMULT_I_H, v>>8 );
}

/* AD9854 Q-Amplitude einstellen */
void ad9854_set_mult_q(uint16_t v)
{
   ad9854_write( AD9854_OSKMULT_Q_L, v );
   ad9854_write( AD9854_OSKMULT_Q_H, v>>8 );
}

