#include "core.h"

#ifndef __AD9854_H
#define __AD9854_H

/* Port B */
#define _MASTER_RESET      PIN_0
#define _SP_SELECT         PIN_1
#define _LED               PIN_2
#define _SHAPED_KEYING     PIN_3

/* Port C */
#define _FSK_BPSK_HOLD     PIN_0
#define _RD                PIN_1
#define _WR                PIN_6
#define _IO_UPD_CLK        PIN_7

/* Union fr Control-Register */
union u_control
{
   struct
   {
      unsigned int digpd :1;
      unsigned int dacpd :1;
      unsigned int qdacpd :1;
      unsigned int :1;
      unsigned int comppd :1;
      unsigned int :3;

      unsigned int refmult:5;
      unsigned int bypll:1;
      unsigned int pllrange:1;
      unsigned int :1;

      unsigned int ieupdc:1;
      unsigned int mode:3;
      unsigned int srcqdac:1;
      unsigned int triangle:1;
      unsigned int clracc:2;

      unsigned int sdoactive:1;
      unsigned int lsb:1;
      unsigned int :2;
      unsigned int oskint:1;
      unsigned int osken:1;
      unsigned int bysinc:1;
      unsigned int :1;
   };
   struct
   {
      unsigned char bt0;
      unsigned char bt1;
      unsigned char bt2;
      unsigned char bt3;
   };
};
typedef union u_control control_reg;

/* Ref-Clock des AD9854 */
#define AD9854_REFCLK            30000000UL

/* Register */
#define AD9854_PHASE1_H          0x00
#define AD9854_PHASE1_L          0x01
#define AD9854_PHASE2_H          0x02
#define AD9854_PHASE2_L          0x03
#define AD9854_FREQ1_5           0x04
#define AD9854_FREQ1_4           0x05
#define AD9854_FREQ1_3           0x06
#define AD9854_FREQ1_2           0x07
#define AD9854_FREQ1_1           0x08
#define AD9854_FREQ1_0           0x09
#define AD9854_FREQ2_5           0x0A
#define AD9854_FREQ2_4           0x0B
#define AD9854_FREQ2_3           0x0C
#define AD9854_FREQ2_2           0x0D
#define AD9854_FREQ2_1           0x0E
#define AD9854_FREQ2_0           0x0F
#define AD9854_DELTA_5           0x10
#define AD9854_DELTA_4           0x11
#define AD9854_DELTA_3           0x12
#define AD9854_DELTA_2           0x13
#define AD9854_DELTA_1           0x14
#define AD9854_DELTA_0           0x15
#define AD9854_UPDCLOCK_3        0x16
#define AD9854_UPDCLOCK_2        0x17
#define AD9854_UPDCLOCK_1        0x18
#define AD9854_UPDCLOCK_0        0x19
#define AD9854_RMPRTCLOCK_2      0x1A
#define AD9854_RMPRTCLOCK_1      0x1B
#define AD9854_RMPRTCLOCK_0      0x1C
#define AD9854_CONTROLWRD_3      0x1D
#define AD9854_CONTROLWRD_2      0x1E
#define AD9854_CONTROLWRD_1      0x1F
#define AD9854_CONTROLWRD_0      0x20
#define AD9854_OSKMULT_I_H       0x21
#define AD9854_OSKMULT_I_L       0x22
#define AD9854_OSKMULT_Q_H       0x23
#define AD9854_OSKMULT_Q_L       0x24
#define AD9854_OSKRMPRT          0x25
#define AD9854_QDAC_H            0x26
#define AD9854_QDAC_L            0x27

/* AD9854-Daten anlegen */
void ad9854_set_data( uint8_t data );

/* AD9854-Adresse anlegen */
void ad9854_set_addr( uint8_t addr );

/* AD9854-Reset */
void ad9854_reset( void );

/* AD9854 initialisieren */
void ad9854_init( void );

/* AD9854-Register beschreiben */
void ad9854_write( uint8_t addr, uint8_t data );

/* AD9854 Phase 1 einstellen */
void ad9854_set_phase_1(uint16_t v );

/* AD9854 Phase 2 einstellen */
void ad9854_set_phase_2(uint16_t v );

/* AD9854 Frequenz 1 einstellen */
void ad9854_set_freq_1(uint64_t f);

/* AD9854 Frequenz 2 einstellen */
void ad9854_set_freq_2(uint64_t f);

/* AD9854 Delta-Frequenz einstellen */
void ad9854_set_delta_freq(uint64_t f);

/* AD9854 Update-Clock einstellen */
void ad9854_set_update_clock(uint32_t v );

/* AD9854 Ramp-Rate Clock einstellen */
void ad9854_set_ramp_rate_clock( uint32_t v );

/* AD9854 Control-Register beschreiben */
void ad9854_set_control_reg( uint32_t v );

/* AD9854 OSK-Ramp-Rate einstellen */
void ad9854_set_osk_ramp_rate(uint16_t v);

/* AD9854 I-Amplitude einstellen */
void ad9854_set_mult_i(uint16_t v);

/* AD9854 Q-Amplitude einstellen */
void ad9854_set_mult_q(uint16_t v);

#endif 
