#include "lcd.h"


union
{
   struct
   {
      unsigned SR_D0 : 1;
      unsigned SR_D1 : 1;
      unsigned SR_D2 : 1;
      unsigned SR_D3 : 1;
      unsigned SR_D4 : 1;
      unsigned SR_D5 : 1;
      unsigned SR_D6 : 1;
      unsigned SR_D7 : 1;
   };
   struct
   {
      unsigned char sr_byte;
   };
}lcd;


/* Schieberegister aktualisieren */
void sr_update( unsigned char b )
{
   byte_out = b;
   io_update = WAITING_FOR_UPDATE;
   while( io_update != DONE );
}

/* LCD initialisieren */
void lcd_init(void)
{
   lcd.sr_byte = 0;
   sr_update( lcd.sr_byte );

   delay_ms(100);
   lcd_write_nibble(0x03);
   delay_ms(5);
   lcd_clk();
   delay_us(160);
   lcd_clk();
   delay_us(160);
   lcd_write_nibble(0x02);
   delay_us(160);
   lcd_write_cmd(0x28);       // Kommando: set 4-bit mode / 2 lines
   delay_us(160);
   lcd_write_cmd(0x10);       // Kommando: cursor move & shift left
   delay_us(160);
   lcd_write_cmd(0x06);       // Kommando: entry mode = increment
   delay_us(160);
   lcd_write_cmd(0b1100);     // Kommando: Display einschalten
   delay_us(160);
   lcd_write_cmd(0x01);       // Kommando: Display lschen
   delay_ms(40);
}

/* bernahmeimpuls ausgeben */
void lcd_clk(void)
{
   delay_us(100);
   lcd.enable = 1;
   sr_update( lcd.sr_byte );
   delay_us(100);
   lcd.enable = 0;
   sr_update( lcd.sr_byte );
}

/* Nibble an LCD senden */
void lcd_write_nibble(unsigned char data)
{
   lcd.d4 = (data & 0b0001) ? 1:0;
   lcd.d5 = (data & 0b0010) ? 1:0;
   lcd.d6 = (data & 0b0100) ? 1:0;
   lcd.d7 = (data & 0b1000) ? 1:0;
   lcd_clk();
}

/* Byte an LCD senden */
void lcd_write_byte(unsigned char data)
{
   lcd_write_nibble(data>>4);
   lcd_write_nibble(data);
}   

/* Kommando an LCD senden */
void lcd_write_cmd(unsigned char data)
{
   lcd.rs = 0;
   sr_update( lcd.sr_byte );
   lcd_write_byte(data);
}

/* Zeichen an LCD senden */
void lcd_write_char(unsigned char data)
{
   lcd.rs = 1;
   sr_update( lcd.sr_byte );
   lcd_write_byte(data);
}

/* Kursor in Zeile setzen */
void lcd_set_row(unsigned short row)
{
   switch (row)
   {
      case 1: lcd_write_cmd(0x80);break;       
      case 2: lcd_write_cmd(0x80+40);break;
      default:lcd_write_cmd(0x80);break;          
   }
}

/* String an LCD senden */
void lcd_write_string(unsigned short pos,char *lcd_str)
{
   lcd_set_row(pos);
   while (*lcd_str != 0)
   {
      lcd_write_char(*lcd_str++);
   }
}



