#include "core.h"
#include "lcd.h"
#include "ad9854.h"
#include "timer.h"


/*
------------------------------------------------------------------------------------------------------
Beschreibung:  Neue Firmware fr das AD9854-Board von Ebay
Version:       v00.1  |  06.05.2014  
Autor:         Achim Dbler

               
Log:           v00.1 
                     > LCD wird ber Schieberegister angesteuert (74xx595)  
                     > Daten (z.B. fr Quadratur-Encoder) werden ber ein Schieberegister eingelesen (74xx166)
                     > Timer-Interrupt (behandelt die Schieberegister)
                     > AD9854-Basisfunktionen implementiert
------------------------------------------------------------------------------------------------------
*/

/* System initialisieren */
void io_init( void )
{
   /* Port C */
   PORTC = 0;                 // Port-Register zurcksetzen
   DDRC = 0;                  // Port C --> hochohmig 
   DDRC |= _FSK_BPSK_HOLD;
   DDRC |= _RD;
   DDRC |= _WR;
   //DDRC |= _IO_UPD_CLK;    
   PORTC |= _RD;              // nRD --> Hi (nicht lesen!)

   /* Port B */
   PORTB = 0;
   DDRB = 0;
   DDRB |= _MASTER_RESET;
   DDRB |= _SP_SELECT;
   DDRB |= _LED;
   DDRB |= _SHAPED_KEYING;

   /* Port A */
   PORTA = 0;
   DDRA = 0xFF;

   /* Port D */
   PORTD = 0;
   DDRD |= PIN_2;
   DDRD |= PIN_3;
   DDRD |= PIN_4;
   DDRD |= PIN_5;
   DDRD |= PIN_6;
   DDRD |= PIN_7;
   
   /* JTAG-Pins freigeben */
   delay_ms(100);
   MCUCSR = (1<<JTD);
   MCUCSR = (1<<JTD);
   
   /* Schieberegister (74xx595 / 74xx166) Pins */
   DDRC |= PIN_2 | PIN_3  | PIN_4;   
}

void toggle_led( void )
{
   if ( PORTB & _LED )
   {
      PORTB &= ~_LED;                            
   }
   else
   {
      PORTB |= _LED;      
   }
}
      
      
int main(void)
{  
   io_init();              /* Pins initialisieren                     */
   ad9854_init();          /* AD9854 initialisieren                   */
   timer_init();           /* Timer initialisieren                    */
   lcd_init();             /* LCD initialisieren                      */
   
   
   while(1)
   {      
      char str[20];
      static int i;
      
      /* IN / OUT Test */
      sprintf(str,"Input:%3u",byte_in);
      lcd_write_string(1,str);
      sprintf(str,"Output:%3u",i++);
      lcd_write_string(2,str);
      delay_ms(10);
   }


}


