#include "timer.h"
#include "lcd.h"

void toggle_led( void );

/* Timer initialisieren */
void timer_init( void )
{
   /* Timer konfigurieren */
// TCCR0 = 0x03; // --> F = 8MHz / 64 / 256 = 488 Hz
   TCCR0 = 0x02; // --> F = 8MHz / 8 / 256 = 3906 Hz
   TIMSK |= 1<<TOIE0;
   
   /* Interrupt einschalten */
   sei(); 
}

volatile unsigned char byte_out;
volatile unsigned char byte_in;
volatile unsigned char io_update;

/* Timer ISR */
ISR (TIMER0_OVF_vect)
{
   int n;
   static int cnt;
   unsigned char tmp=0;
   
   /* Blinky :) */
   if ( cnt )
   {
      cnt--;
   }
   else
   {
      cnt = 390;
      toggle_led();
   }

   /* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! */
   /* !!!!!!!!!!!!!!!   A C H T U N G   !!!!!!!!!!!!!!! */
   /* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! */
   // Beide Schieberegister werden uerst "giftig" angesteuert. Um Leitungen einzusparen, werden alle CS-Leitungen fest verdrahtet. 
   // Daher darf zu keinem Zeitpunkt etwas in die Leitung "spucken", sonst fllt das LCD aus und/oder es wird nur Schrott empfangen!
   // Die Leitungslngen von SR_DO, SR_DI, SR_CLK und SR_LAT MSSEN(!!) daher so kurz wie mglich gehalten werden, damit die Sache funktioniert!
   
   /* 74xx595: seriell beschreiben                      */
   /* 74xx166: erster Clock-Puls latcht die Input-Daten */
   for(n=0x80;n;n>>=1)
   {
      if (byte_out & n)
      {
         
         PORTC |= SR_DO;
      }
      else
      {
         PORTC &= ~SR_DO;
      }
      PORTC &= ~SR_CLK;
      Nop();
      PORTC |= SR_CLK;
      Nop();
   }
   
   /* 74xx595: Output-Daten werden gelatcht             */
   /* 74xx166: serieller Mode wird aktiviert            */
   PORTC |= SR_LAT;
   Nop();
   
   /* 74xx166: Daten seriell auslesen...                */
   for(n=0x80;n;n>>=1)
   {
      if (PINC & SR_DI) tmp |= n;
      
      PORTC &= ~SR_CLK;
      Nop();
      PORTC |= SR_CLK;
      Nop();
   }      
   
   /* 74xx595: Register abwhlen                        */
   PORTC &= ~SR_LAT;
   
   byte_in = tmp;
   io_update = DONE;
}